summaryrefslogtreecommitdiffstats
path: root/src/sound/sound.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound/sound.h')
-rw-r--r--src/sound/sound.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/sound/sound.h b/src/sound/sound.h
index c2943f2..45ec7e1 100644
--- a/src/sound/sound.h
+++ b/src/sound/sound.h
@@ -143,19 +143,19 @@ enum SoundNext
/**
-* @class CSound
+* @class CSoundInterface
*
* @brief Sound plugin interface
*
*/
-class CSound : public CPluginInterface
+class CSoundInterface : public CPluginInterface
{
public:
- CSound() {
+ CSoundInterface() {
//CInstanceManager::getInstance().AddInstance(CLASS_SOUND, this);
//m_iMan->AddInstance(CLASS_SOUND, this);
};
- virtual ~CSound() = 0;
+ virtual ~CSoundInterface() = 0;
/** Function to initialize sound device
* @param bool b3D - enable support for 3D sound
@@ -163,7 +163,7 @@ class CSound : public CPluginInterface
virtual bool Create(bool b3D) = 0;
/** Function called to cache all sound effect files.
* Function calls \link CSound::Cache() \endlink for each file
*/
virtual void CacheAll() = 0;
@@ -163,7 +163,7 @@ class CSound : public CPluginInterface
virtual bool Create(bool b3D) = 0;
/** Function called to cache all sound effect files.
- * Function calls \link CSound::Cache() \endlink for each file
+ * Function calls \link CSoundInterface::Cache() \endlink for each file
*/
virtual void CacheAll() = 0;